@@ -1,7 +1,7 @@
 as.party <- function(obj, ...)
     UseMethod("as.party")
 
-as.party.rpart <- function(obj, ...) {
+as.party.rpart <- function(obj, data = TRUE, ...) {
 
     ff <- obj$frame
     n  <- nrow(ff)
@@ -43,22 +43,29 @@ as.party.rpart <- function(obj, ...) {
 
     rpart_onesplit <- function(j) {
         if (j < 1) return(NULL)
+
+	idj <- which(rownames(obj$split)[j] == names(mf))
         ### numeric
         if (abs(obj$split[j, "ncat"]) == 1) {
-            ret <- partysplit(varid = which(rownames(obj$split)[j] == names(mf)),
+            ret <- partysplit(varid = idj,
                       breaks = as.double(obj$split[j, "index"]),
                       right = FALSE,
-                      index = if(obj$split[j, "ncat"] > 0) 2:1)
+                      index = if(obj$split[j, "ncat"] > 0) 2L:1L)
         } else {
             index <- obj$csplit[obj$split[j, "index"],]
+	    mfj <- mf[, rownames(obj$split)[j]]
             ### csplit has columns 1L:max(nlevels) for all factors
             ### index <- index[1L:obj$split[j, "ncat"]] ??? safer ???
-            index <- index[1L:nlevels(mf[, rownames(obj$split)[j]])]
+            index <- index[1L:nlevels(mfj)]
             index[index == 2L] <- NA ### level not present in split
             index[index == 3L] <- 2L  ### 1..left, 3..right
-            ret <- partysplit(varid = which(rownames(obj$split)[j] == names(mf)),
-                      index = as.integer(index))
-        }
+	    if(inherits(mfj, "ordered")) {
+                ret <- partysplit(varid = idj, breaks = which(diff(index) != 0L) + 1L,
+		  right = FALSE, index = unique(index))
+	    } else {
+                ret <- partysplit(varid = idj, index = as.integer(index))
+            }
+	}
         ret
     }
                       
@@ -87,8 +94,8 @@ as.party.rpart <- function(obj, ...) {
 
     node <- rpart_node(1)
 
-    rval <- party(node = node, data = mf[0L,], fitted = fitted,
-      terms = obj$terms, info = list(method = "rpart"))
+    rval <- party(node = node, data = if(data) mf else mf[0L,],
+      fitted = fitted, terms = obj$terms, info = list(method = "rpart"))
     class(rval) <- c("constparty", class(rval))
     return(rval)
 }
@@ -101,8 +108,8 @@ model.frame.rpart <- function(formula, ...) {
   mf <- formula$call
   mf <- mf[c(1L, match(c("formula", "data", "subset", "na.action", "weights"), names(mf), 0L))]
   if (is.null(mf$na.action)) mf$na.action <- rpart::na.rpart
-  mf$drop.unused.levels <- TRUE
-  mf[[1L]] <- as.name("model.frame")
+  # mf$drop.unused.levels <- TRUE
+  mf[[1L]] <- quote(stats::model.frame)
   
   ## use terms instead of formula in call
   mf$formula <- formula$terms
@@ -113,7 +120,7 @@ model.frame.rpart <- function(formula, ...) {
   return(mf)
 }
 
-as.party.Weka_tree <- function(obj, ...) {
+as.party.Weka_tree <- function(obj, data = TRUE, ...) {
 
   ## needs RWeka and rJava
   stopifnot(requireNamespace("RWeka"))
@@ -185,7 +192,7 @@ as.party.Weka_tree <- function(obj, ...) {
   if(j48) {
     pty <- party(
       node = node,
-      data = mf[0L,],
+      data = if(data) mf else mf[0L,],
       fitted = data.frame("(fitted)" = fitted_node(node, mf),
         		  "(response)" = model.response(mf),
         		  check.names = FALSE),
